/*
 * Copyright or © or Copr. Fabien Michel, Olivier Gutknecht, Jacques Ferber (1997)

fmichel@lirmm.fr
olg@no-distance.net
ferber@lirmm.fr

This software is a computer program whose purpose is to 
provide a lightweight Java library for designing and simulating Multi-Agent Systems (MAS).

This software is governed by the CeCILL-C license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-C
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-C license and that you accept its terms.
 */

package madkit.gui;

import java.awt.Container;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.print.PageFormat;
import java.awt.print.Printable;
import java.awt.print.PrinterException;

/**
 * Interface that adds the printing feature to MDK frames
 * 
 * @author Fabien Michel
 * @since MaDKit 5.1.1
 */
public interface PrintableFrame extends Printable {

    @Override
    public default int print(Graphics graphics, PageFormat pageFormat, int pageIndex) throws PrinterException {
	if (pageIndex > 0) { /* We have only one page, and 'page' is zero-based */
	    return NO_SUCH_PAGE;
	}
	Graphics2D g2d = (Graphics2D) graphics;
	final double imageableX = pageFormat.getImageableX();
	g2d.translate(imageableX, pageFormat.getImageableY());

	getPrintableContainer().printAll(graphics);
	return PAGE_EXISTS;
    }

    public default Container getPrintableContainer() {
	return (Container) this;
    }
}
